Package: SYNCSA
Type: Package
Title: Analysis of Functional and Phylogenetic Patterns in
        Metacommunities
Version: 1.3.5
Date: 2025-08-21
Authors@R: person(given = c("Vanderlei", "Julio"),
                      family = "Debastiani",
                      role = c("aut", "cre"),
                      email = "vanderleidebastiani@yahoo.com.br")
Maintainer: Vanderlei Julio Debastiani <vanderleidebastiani@yahoo.com.br>
Imports: vegan, FD, permute, RcppArmadillo, utils, stats, graphics,
        parallel
Description: Analysis of metacommunities based on functional traits and
    phylogeny of the community components. The functions that are offered here
    implement for the R environment methods that have been available in the
    'SYNCSA' application written in C++ (by Valerio Pillar, available at 
    <http://ecoqua.ecologia.ufrgs.br/SYNCSA.html>).
License: GPL-2
Encoding: UTF-8
RoxygenNote: 7.3.2
Collate: 'CollectNames.R' 'ProgressBAR.R' 'belonging.R' 'cent.norm.R'
        'coinertia.partial.syncsa.R' 'coinertia.syncsa.R'
        'cor.matrix.R' 'cor.matrix.bf.R' 'cor.matrix.partial.R'
        'cor.matrix.rao.R' 'matmult.syncsa.R' 'matrix.p.R' 'matrix.t.R'
        'matrix.w.transformation.R' 'matrix.x.R' 'optimal.R'
        'organize.syncsa.R' 'part.cor.R' 'pca.R' 'permut.row.matrix.R'
        'permut.vector.R' 'plot.pcasyncsa.R' 'print.optimal.R'
        'syncsa.R' 'print.syncsa.R' 'pro.matrix.R' 'pro.matrix.bf.R'
        'pro.matrix.partial.R' 'pro.matrix.rao.R' 'procrustes.syncsa.R'
        'procrustes.partial.syncsa.R' 'rao.diversity.R' 'rv.matrix.R'
        'rv.matrix.bf.R' 'rv.matrix.partial.R' 'rv.matrix.rao.R'
        'startup.R' 'syncsa.obs.R' 'var.dummy.R' 'var.type.R'
NeedsCompilation: no
Packaged: 2025-08-22 01:13:04 UTC; vanderleidebastiani
Author: Vanderlei Julio Debastiani [aut, cre]
Repository: CRAN
Date/Publication: 2025-08-22 09:30:23 UTC
Built: R 4.6.0; ; 2026-04-26 04:27:55 UTC; unix
