# Generated by roxygen2: do not edit by hand

S3method(plot,pcasyncsa)
S3method(print,optimal)
S3method(print,syncsa)
export(CollectNames)
export(ProgressBAR)
export(belonging)
export(cent.norm)
export(coinertia.partial.syncsa)
export(coinertia.syncsa)
export(cor.matrix)
export(cor.matrix.bf)
export(cor.matrix.partial)
export(cor.matrix.rao)
export(matmult.syncsa)
export(matrix.p)
export(matrix.t)
export(matrix.w.transformation)
export(matrix.x)
export(optimal)
export(organize.syncsa)
export(part.cor)
export(pca)
export(permut.row.matrix)
export(permut.vector)
export(pro.matrix)
export(pro.matrix.bf)
export(pro.matrix.partial)
export(pro.matrix.rao)
export(procrustes.partial.syncsa)
export(procrustes.syncsa)
export(rao.diversity)
export(rv.matrix)
export(rv.matrix.bf)
export(rv.matrix.partial)
export(rv.matrix.rao)
export(syncsa)
export(syncsa.obs)
export(var.dummy)
export(var.type)
importFrom(FD,gowdis)
importFrom(RcppArmadillo,fastLmPure)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(parallel,makeCluster)
importFrom(parallel,parRapply)
importFrom(parallel,stopCluster)
importFrom(permute,Plots)
importFrom(permute,Within)
importFrom(permute,how)
importFrom(permute,shuffleSet)
importFrom(stats,as.dist)
importFrom(stats,cor)
importFrom(stats,lm)
importFrom(stats,prcomp)
importFrom(stats,residuals)
importFrom(utils,combn)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(vegan,beals)
importFrom(vegan,protest)
importFrom(vegan,vegdist)
importFrom(vegan,wcmdscale)
