\encoding{UTF-8}
\name{ADRS}
\alias{ADRS}
\docType{data}
\title{Artificial Data for Run SYNCSA}
\usage{
data(ADRS)
}
\description{Artificial data for run SYNCSA.}
\format{
  A list with:.
  \describe{
    \item{commnunity}{Community data, observations of six species in ten sites.}
    \item{traits}{Matrix data of species described by two traits.}
    \item{phylo}{Matrix containing phylogenetic distance between species.}
    \item{envir}{One environmental variable for each community.}
  }
}
\examples{
data(ADRS)
}
\keyword{datasets}
