% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/procrustes.syncsa.R,
%   R/procrustes.partial.syncsa.R
\encoding{UTF-8}
\name{procrustes.syncsa}
\alias{procrustes.syncsa}
\alias{procrustes.partial.syncsa}
\title{Procrustes and Partial Procrustes correlations.}
\usage{
procrustes.syncsa(x, y)

procrustes.partial.syncsa(x, y, z)
}
\arguments{
\item{x, y}{Matrix that will be correlated.}

\item{z}{Matrix whose effect will be removed from the correlation between x
and y.}
}
\value{
Procrustes correlation between matrices.
}
\description{
Function to obtain the Procrustes correlation between two matrices and
partial Procrustes correlation between three matrices.
}
\details{
The function procrustes.syncsa is a small change in the function
\code{\link[vegan]{procrustes}}. The function uses a correlation-like statistic
derived from the symmetric Procrustes sum of squares. Partial Procrustes
correlations is obtained by Procrustes correlation of residuals between
each variable in z being used as linear predictor of all variables in x and y.
For more details, see \code{\link{syncsa}}.
}
\references{
Peres-Neto, P.R. and Jackson, D.A. (2001). How well do
multivariate data sets match? The advantages of a Procrustean
superimposition approach over the Mantel test. Oecologia 129: 169-178.
}
\seealso{
\code{\link{syncsa}}, \code{\link{cor.matrix}}
}
\author{
Vanderlei Julio Debastiani <vanderleidebastiani@yahoo.com.br>
}
\keyword{SYNCSA}
